@@ -20,7 +20,7 @@ ax.set(xticks=range(9), xticklabels=labels, title="Hover over a bar")
 cursor = mplcursors.cursor(hover=mplcursors.HoverMode.Transient)
 @cursor.connect("add")
 def on_add(sel):
-    x, y, width, height = sel.artist[sel.target.index].get_bbox().bounds
+    x, y, width, height = sel.artist[sel.index].get_bbox().bounds
     sel.annotation.set(text=f"{x+width/2}: {height}",
                        position=(0, 20), anncoords="offset points")
     sel.annotation.xy = (x + width / 2, y + height)
