@@ -7,6 +7,7 @@ import sys
 import weakref
 from weakref import WeakKeyDictionary, WeakSet
 
+import matplotlib as mpl
 from matplotlib.axes import Axes
 from matplotlib.container import Container
 from matplotlib.figure import Figure
@@ -95,11 +96,15 @@ def _iter_axes_subartists(ax):
 
 def _is_alive(artist):
     """Check whether *artist* is still present on its parent axes."""
-    return bool(artist
-                and artist.axes
-                and (artist.container in artist.axes.containers
-                     if isinstance(artist, _pick_info.ContainerArtist) else
-                     artist in _iter_axes_subartists(artist.axes)))
+    return bool(
+        artist
+        and artist.axes
+        # `cla()` clears `.axes` since matplotlib/matplotlib#24627 (3.7);
+        # iterating over subartists can be very slow.
+        and (getattr(mpl, "__version_info__", ()) >= (3, 7)
+             or (artist.container in artist.axes.containers
+                 if isinstance(artist, _pick_info.ContainerArtist) else
+                 artist in _iter_axes_subartists(artist.axes))))
 
 
 def _reassigned_axes_event(event, ax):
@@ -269,7 +274,7 @@ class Cursor:
             action, key = bindings_items[i]
             for j in range(i):
                 other_action, other_key = bindings_items[j]
-                if key == other_key:
+                if key == other_key and key is not None:
                     raise ValueError(
                         f"Duplicate bindings: {key} is used for "
                         f"{other_action} and for {action}")
@@ -288,8 +293,6 @@ class Cursor:
     @property
     def artists(self):
         """The tuple of selectable artists."""
-        # Work around matplotlib/matplotlib#6982: `cla()` does not clear
-        # `.axes`.
         return tuple(filter(_is_alive, (ref() for ref in self._artists)))
 
     @property
@@ -376,7 +379,7 @@ class Cursor:
         get_cached_renderer = (
             figure.canvas.get_renderer
             if hasattr(figure.canvas, "get_renderer")
-            else axes.get_renderer_cache)  # matplotlib <3.6.
+            else axes.get_renderer_cache)  # mpl<3.6.
         renderer = get_cached_renderer()
         if renderer is None:
             figure.canvas.draw()  # Needed below anyways.
@@ -539,8 +542,8 @@ class Cursor:
         Remove all `Selection`\\s, disconnect all callbacks, and allow the
         cursor to be garbage collected.
         """
-        for disconnectors in self._disconnectors:
-            disconnectors()
+        for disconnector in self._disconnectors:
+            disconnector()
         for sel in self.selections:
             self.remove_selection(sel)
         for s in type(self)._keep_alive.values():
