@@ -19,6 +19,7 @@ from matplotlib.axes import Axes
 from matplotlib.backend_bases import RendererBase
 from matplotlib.collections import (
     LineCollection, PatchCollection, PathCollection)
+from matplotlib.colorbar import Colorbar
 from matplotlib.container import BarContainer, ErrorbarContainer, StemContainer
 from matplotlib.figure import Figure
 from matplotlib.image import AxesImage
@@ -98,7 +99,7 @@ class ContainerArtist:
 
 
 Selection = namedtuple(
-    "Selection", "artist target_ index dist annotation extras")
+    "Selection", "artist target index dist annotation extras")
 Selection.__doc__ = """
     A selection.
 
@@ -115,11 +116,8 @@ Selection.__eq__ = lambda self, other: self is other
 Selection.__ne__ = lambda self, other: self is not other
 Selection.artist.__doc__ = (
     "The selected artist.")
-Selection.target_.__doc__ = """
-The point picked within the artist, in data coordinates.
-
-:meta private:
-"""
+Selection.target.__doc__ = (
+    "The point picked within the artist, in data coordinates.")
 Selection.index.__doc__ = (
     "The index of the selected point, within the artist data.")
 Selection.dist.__doc__ = (
@@ -131,24 +129,6 @@ Selection.extras.__doc__ = (
     "at the same time as the annotation.")
 
 
-class _Target(np.ndarray):
-    def __new__(cls, sel):
-        obj = np.asarray(sel.target_).view(cls)
-        obj._sel = sel
-        return obj
-
-    @property
-    def index(self):
-        warnings.warn(
-            "Selection.target.index is deprecated and will be removed in the "
-            "future; use Selection.index instead.")
-        return self._sel.index
-
-
-Selection.target = property(
-    _Target, doc="The point picked within the artist, in data coordinates.")
-
-
 @functools.singledispatch
 def compute_pick(artist, event):
     """
@@ -513,14 +493,21 @@ def _call_with_selection(func=None, *, argname="artist"):
     return wrapper
 
 
-def _format_coord_unspaced(ax, xy):
-    # Un-space-pad, remove empty coordinates from the output of
-    # `format_{x,y}data`, and rejoin with newlines.
-    return "\n".join(
-        line for line, empty in zip(
-            re.split(",? +", ax.format_coord(*xy)),
-            itertools.chain(["x=", "y=", "z="], itertools.repeat(None)))
-        if line != empty).rstrip()
+def _format_coord_unspaced(ax, pos):
+    # This used to directly post-process the output of format_coord(), but got
+    # switched to handling special projections separately due to the change in
+    # formatting for rectilinear coordinates.
+    if ax.name == "polar":
+        return ax.format_coord(*pos).replace(", ", "\n")
+    elif ax.name == "3d":  # Need to retrieve the actual line data coordinates.
+        warnings.warn("3d coordinates not supported yet")
+        return ""
+    else:
+        x, y = pos
+        # In mpl<3.3 (before #16776) format_x/ydata included trailing
+        # spaces, hence the rstrip() calls.
+        return (f"x={ax.format_xdata(x).rstrip()}\n"
+                f"y={ax.format_ydata(y).rstrip()}")
 
 
 @functools.singledispatch
@@ -537,29 +524,6 @@ def get_ann_text(sel):
     return ""
 
 
-def _strip_math(s):
-    return cbook.strip_math(s) if len(s) >= 2 and s[0] == s[-1] == "$" else s
-
-
-def _format_scalarmappable_value(artist, idx):  # matplotlib/matplotlib#12473.
-    data = artist.get_array()[idx]
-    if np.ndim(data) == 0:
-        if not artist.colorbar:
-            fig = Figure()
-            ax = fig.subplots()
-            artist.colorbar = fig.colorbar(artist, cax=ax)
-            # This hack updates the ticks without actually paying the cost of
-            # drawing (RendererBase.draw_path raises NotImplementedError).
-            try:
-                ax.yaxis.draw(RendererBase())
-            except NotImplementedError:
-                pass
-        fmt = artist.colorbar.formatter.format_data_short
-        return "[" + _strip_math(fmt(data).strip()) + "]"
-    else:
-        return artist.format_cursor_data(data)  # Includes brackets.
-
-
 @get_ann_text.register(Line2D)
 @get_ann_text.register(LineCollection)
 @get_ann_text.register(PatchCollection)
@@ -576,7 +540,7 @@ def _(sel):
             # to involve an arbitrary scaling).
             and artist.get_array() is not None
             and len(artist.get_array()) == len(artist.get_offsets())):
-        value = _format_scalarmappable_value(artist, sel.index)
+        value = artist.format_cursor_data(artist.get_array()[sel.index])
         text = f"{text}\n{value}"
     if re.match("[^_]", label):
         text = f"{label}\n{text}"
@@ -591,7 +555,7 @@ _Event = namedtuple("_Event", "xdata ydata")
 def _(sel):
     artist = sel.artist
     text = _format_coord_unspaced(artist.axes, sel.target)
-    cursor_text = _format_scalarmappable_value(artist, sel.index)
+    cursor_text = artist.format_cursor_data(artist.get_array()[sel.index])
     return f"{text}\n{cursor_text}"
 
 
@@ -599,9 +563,9 @@ def _(sel):
 @_call_with_selection
 def _(sel):
     artist = sel.artist
-    text = "{}\n{}".format(
+    text = "{}\n({!s}, {!s})".format(
         _format_coord_unspaced(artist.axes, sel.target),
-        (artist.u[sel.index], artist.v[sel.index]))
+        artist.u[sel.index], artist.v[sel.index])
     return text
 
 
@@ -609,9 +573,9 @@ def _(sel):
 @_call_with_selection
 def _(sel):
     artist = sel.artist
-    text = "{}\n{}".format(
+    text = "{}\n({!s}, {!s})".format(
         _format_coord_unspaced(artist.axes, sel.target),
-        (artist.U[sel.index], artist.V[sel.index]))
+        artist.U[sel.index], artist.V[sel.index])
     return text
 
 
@@ -691,7 +655,7 @@ def _move_within_points(sel, xys, *, key):
             new_idx = int(np.floor(sel.index) + 1) % len(xys)
         else:
             return sel
-        sel = sel._replace(target_=xys[new_idx], index=new_idx, dist=0)
+        sel = sel._replace(target=xys[new_idx], index=new_idx, dist=0)
         if np.isfinite(sel.target).all():
             return sel
 
@@ -737,7 +701,7 @@ def _(sel, *, key):
         ymin, ymax = ymax, ymin
     low, high = np.array([[xmin, ymin], [xmax, ymax]])
     target = ((idxs + .5) / ns)[::-1] * (high - low) + low
-    return sel._replace(target_=target, index=tuple(idxs))
+    return sel._replace(target=target, index=tuple(idxs))
 
 
 @move.register(ContainerArtist)
