@@ -1,3 +1,4 @@
+from contextlib import ExitStack
 import copy
 import functools
 import gc
@@ -46,12 +47,6 @@ def cleanup():
             plt.close("all")
 
 
-def _internal_warnings(record):
-    return [
-        warning for warning in record
-        if Path(mplcursors.__file__).parent in Path(warning.filename).parents]
-
-
 def _process_event(name, ax, coords, *args):
     ax.viewLim  # unstale viewLim.
     if name == "__mouse_click__":
@@ -95,7 +90,7 @@ def test_containerartist(ax):
 
 def test_selection_identity_comparison():
     sel0, sel1 = [Selection(artist=None,
-                            target_=np.array([0, 0]),
+                            target=np.array([0, 0]),
                             index=None,
                             dist=0,
                             annotation=None,
@@ -244,9 +239,7 @@ def test_nan(ax, plot_args, click, targets):
 def test_repeated_point(ax):
     ax.plot([0, 1, 1, 2], [0, 1, 1, 2])
     cursor = mplcursors.cursor()
-    with pytest.warns(None) as record:
-        _process_event("__mouse_click__", ax, (.5, .5), 1)
-    assert not _internal_warnings(record)
+    _process_event("__mouse_click__", ax, (.5, .5), 1)  # Should not warn.
 
 
 @pytest.mark.parametrize("origin", ["lower", "upper"])
@@ -258,16 +251,16 @@ def test_image(ax, origin):
     # Annotation text includes image value.
     _process_event("__mouse_click__", ax, (.25, .25), 1)
     sel, = cursor.selections
-    assert _parse_annotation(
-        sel, r"x=(.*)\ny=(.*)\n\[0\]") == approx((.25, .25))
+    assert _parse_annotation(  # Since mpl3.5 the value repr has extra zeros.
+        sel, r"x=(.*)\ny=(.*)\n\[0(?:\.00)?\]") == approx((.25, .25))
     # Moving around.
     _process_event("key_press_event", ax, (.123, .456), "shift+right")
     sel, = cursor.selections
-    assert _parse_annotation(sel, r"x=(.*)\ny=(.*)\n\[1\]") == (1, 0)
+    assert _parse_annotation(sel, r"x=(.*)\ny=(.*)\n\[1(?:\.00)?\]") == (1, 0)
     assert array[sel.index] == 1
     _process_event("key_press_event", ax, (.123, .456), "shift+right")
     sel, = cursor.selections
-    assert _parse_annotation(sel, r"x=(.*)\ny=(.*)\n\[0\]") == (0, 0)
+    assert _parse_annotation(sel, r"x=(.*)\ny=(.*)\n\[0(?:\.00)?\]") == (0, 0)
     assert array[sel.index] == 0
     _process_event("key_press_event", ax, (.123, .456), "shift+up")
     sel, = cursor.selections
@@ -276,7 +269,7 @@ def test_image(ax, origin):
     assert array[sel.index] == {"upper": 4, "lower": 2}[origin]
     _process_event("key_press_event", ax, (.123, .456), "shift+down")
     sel, = cursor.selections
-    assert _parse_annotation(sel, r"x=(.*)\ny=(.*)\n\[0\]") == (0, 0)
+    assert _parse_annotation(sel, r"x=(.*)\ny=(.*)\n\[0(?:\.00)?\]") == (0, 0)
     assert array[sel.index] == 0
 
     cursor = mplcursors.cursor()
@@ -388,8 +381,7 @@ def test_dataless_errorbar(ax):
 
 def test_stem(ax):
     try:  # stem use_line_collection API change.
-        with pytest.warns(None):
-            ax.stem([1, 2, 3], use_line_collection=True)
+        ax.stem([1, 2, 3], use_line_collection=True)
     except TypeError:
         ax.stem([1, 2, 3])
     cursor = mplcursors.cursor()
@@ -409,10 +401,9 @@ def test_stem(ax):
 def test_misc_artists(ax, plotter, warns):
     plotter(ax)
     cursor = mplcursors.cursor()
-    with pytest.warns(None) as record:
+    with pytest.warns(UserWarning) if warns else ExitStack():
         _process_event("__mouse_click__", ax, (.5, .5), 1)
     assert len(cursor.selections) == 0
-    assert len(_internal_warnings(record)) == warns
 
 
 def test_indexless_projections(fig):
@@ -645,6 +636,7 @@ def test_invalid_args():
                   bindings={"foo": 42})
     pytest.raises(ValueError, mplcursors.cursor,
                   bindings={"select": 1, "deselect": 1})
+    mplcursors.cursor(bindings={"select": None, "deselect": None})
     pytest.raises(ValueError, mplcursors.cursor().connect,
                   "foo")
 
